@@ -574,7 +574,7 @@ void MainWindow::on_pushButtonLumLogFile_clicked()
         return;
     }
     QFileInfo viewer("/usr/bin/mx-viewer");
-    QFileInfo viewer2("/usr/bin/antix-viewer");
+    QFileInfo viewer2("/usr/bin/xlinks2");
     QString rootrunoption = QString();
     QString cmd;
 
@@ -588,7 +588,7 @@ void MainWindow::on_pushButtonLumLogFile_clicked()
     if (viewer.exists())
         cmd = QString("mx-viewer %1 '%2' &").arg(url).arg(lum.baseName());
     else if (viewer2.exists())
-        cmd = QString("antix-viewer %1 '%2' &").arg(url).arg(lum.baseName());
+        cmd = QString("xlinks2 %1 '%2' &").arg(url).arg(lum.baseName());
     else
         cmd = QString(rootrunoption + "\"DISPLAY=$DISPLAY xdg-open %1\" &").arg(url);
     system(cmd.toUtf8());
